@@ -15,18 +15,18 @@ import sys
 from typing import List
 
 from .literals import (
-    AdditionalConstraintsElement,
-    AuthResources,
-    DeliveryMethod,
-    MFAMode,
-    MfaTypesElement,
-    Mode,
-    OAuthGrantType,
-    OAuthScopesElement,
-    RequiredSignUpAttributesElement,
-    ResolutionStrategy,
-    SignInMethod,
-    Status,
+    AdditionalConstraintsElementType,
+    AuthResourcesType,
+    DeliveryMethodType,
+    MFAModeType,
+    MfaTypesElementType,
+    ModeType,
+    OAuthGrantTypeType,
+    OAuthScopesElementType,
+    RequiredSignUpAttributesElementType,
+    ResolutionStrategyType,
+    SignInMethodType,
+    StatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -110,7 +110,7 @@ BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
 BackendAPIAuthTypeTypeDef = TypedDict(
     "BackendAPIAuthTypeTypeDef",
     {
-        "Mode": Mode,
+        "Mode": ModeType,
         "Settings": "BackendAPIAppSyncAuthSettingsTypeDef",
     },
     total=False,
@@ -119,7 +119,7 @@ BackendAPIAuthTypeTypeDef = TypedDict(
 BackendAPIConflictResolutionTypeDef = TypedDict(
     "BackendAPIConflictResolutionTypeDef",
     {
-        "ResolutionStrategy": ResolutionStrategy,
+        "ResolutionStrategy": ResolutionStrategyType,
     },
     total=False,
 )
@@ -202,7 +202,7 @@ CreateBackendAPIResponseTypeDef = TypedDict(
 _RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef",
     {
-        "DeliveryMethod": DeliveryMethod,
+        "DeliveryMethod": DeliveryMethodType,
     },
 )
 _OptionalCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
@@ -233,7 +233,7 @@ CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
 _RequiredCreateBackendAuthMFAConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthMFAConfigTypeDef",
     {
-        "MFAMode": MFAMode,
+        "MFAMode": MFAModeType,
     },
 )
 _OptionalCreateBackendAuthMFAConfigTypeDef = TypedDict(
@@ -254,8 +254,8 @@ class CreateBackendAuthMFAConfigTypeDef(
 _RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthOAuthConfigTypeDef",
     {
-        "OAuthGrantType": OAuthGrantType,
-        "OAuthScopes": List[OAuthScopesElement],
+        "OAuthGrantType": OAuthGrantTypeType,
+        "OAuthScopes": List[OAuthScopesElementType],
         "RedirectSignInURIs": List[str],
         "RedirectSignOutURIs": List[str],
     },
@@ -285,7 +285,7 @@ _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
 _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
     {
-        "AdditionalConstraints": List[AdditionalConstraintsElement],
+        "AdditionalConstraints": List[AdditionalConstraintsElementType],
     },
     total=False,
 )
@@ -301,7 +301,7 @@ class CreateBackendAuthPasswordPolicyConfigTypeDef(
 _RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthResourceConfigTypeDef",
     {
-        "AuthResources": AuthResources,
+        "AuthResources": AuthResourcesType,
         "Service": Literal["COGNITO"],
         "UserPoolConfigs": "CreateBackendAuthUserPoolConfigTypeDef",
     },
@@ -337,8 +337,8 @@ CreateBackendAuthResponseTypeDef = TypedDict(
 _RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
     {
-        "RequiredSignUpAttributes": List[RequiredSignUpAttributesElement],
-        "SignInMethod": SignInMethod,
+        "RequiredSignUpAttributes": List[RequiredSignUpAttributesElementType],
+        "SignInMethod": SignInMethodType,
         "UserPoolName": str,
     },
 )
@@ -468,7 +468,7 @@ GetBackendAPIModelsResponseTypeDef = TypedDict(
     "GetBackendAPIModelsResponseTypeDef",
     {
         "Models": str,
-        "Status": Status,
+        "Status": StatusType,
     },
     total=False,
 )
@@ -589,7 +589,7 @@ RemoveBackendConfigResponseTypeDef = TypedDict(
 SettingsTypeDef = TypedDict(
     "SettingsTypeDef",
     {
-        "MfaTypes": List[MfaTypesElement],
+        "MfaTypes": List[MfaTypesElementType],
         "SmsMessage": str,
     },
     total=False,
@@ -629,7 +629,7 @@ UpdateBackendAPIResponseTypeDef = TypedDict(
 UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
     "UpdateBackendAuthForgotPasswordConfigTypeDef",
     {
-        "DeliveryMethod": DeliveryMethod,
+        "DeliveryMethod": DeliveryMethodType,
         "EmailSettings": "EmailSettingsTypeDef",
         "SmsSettings": "SmsSettingsTypeDef",
     },
@@ -647,7 +647,7 @@ UpdateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
 UpdateBackendAuthMFAConfigTypeDef = TypedDict(
     "UpdateBackendAuthMFAConfigTypeDef",
     {
-        "MFAMode": MFAMode,
+        "MFAMode": MFAModeType,
         "Settings": "SettingsTypeDef",
     },
     total=False,
@@ -657,8 +657,8 @@ UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
     "UpdateBackendAuthOAuthConfigTypeDef",
     {
         "DomainPrefix": str,
-        "OAuthGrantType": OAuthGrantType,
-        "OAuthScopes": List[OAuthScopesElement],
+        "OAuthGrantType": OAuthGrantTypeType,
+        "OAuthScopes": List[OAuthScopesElementType],
         "RedirectSignInURIs": List[str],
         "RedirectSignOutURIs": List[str],
         "SocialProviderSettings": "SocialProviderSettingsTypeDef",
@@ -669,7 +669,7 @@ UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
 UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
     {
-        "AdditionalConstraints": List[AdditionalConstraintsElement],
+        "AdditionalConstraints": List[AdditionalConstraintsElementType],
         "MinimumLength": float,
     },
     total=False,
@@ -678,7 +678,7 @@ UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
 _RequiredUpdateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredUpdateBackendAuthResourceConfigTypeDef",
     {
-        "AuthResources": AuthResources,
+        "AuthResources": AuthResourcesType,
         "Service": Literal["COGNITO"],
         "UserPoolConfigs": "UpdateBackendAuthUserPoolConfigTypeDef",
     },
